.. image:: https://travis-ci.org/lazka/senf.svg?branch=master
    :target: https://travis-ci.org/lazka/senf

**Senf** introduces a new platform native string type called `fsnative`. It
adds functions to convert text, bytes and paths to and from that new type and
helper functions to integrate it nicely with the Python stdlib.

**Senf** supports Python 2.7, 3.3+, works with PyPy, works on Linux, Windows,
macOS, is MIT licensed, and only depends on the stdlib. It does not monkey
patch anything in the stdlib.

For more info see https://senf.readthedocs.io/

.. image:: https://github.com/lazka/senf/raw/master/docs/images/ls.png
    :width: 699
    :height: 470

.. image:: https://github.com/lazka/senf/raw/master/docs/images/ansi.png
    :width: 699
    :height: 470
